@@ -45,7 +45,7 @@ from nuitka.utils.FileOperations import (
     relpath,
     resolveShellPatternToFilenames,
 )
-from nuitka.utils.Importing import getSharedLibrarySuffixes
+from nuitka.utils.Importing import getExtensionModuleSuffixes
 from nuitka.utils.ModuleNames import ModuleName
 from nuitka.utils.Utils import isMacOS
 
@@ -69,6 +69,14 @@ def getDataFileTags(dest_path):
     return result
 
 
+def hasDataFileTag(tag):
+    for value in data_file_tags:
+        _pattern, tags = value.rsplit(":", 1)
+
+        if tag in tags:
+            return True
+
+
 def decodeDataFileTags(tags):
     """In many places, strings are accepted for tags, convert to OrderedSet for internal use."""
 
@@ -214,7 +222,7 @@ default_ignored_suffixes = (
     ".bin",
 )
 
-default_ignored_suffixes += getSharedLibrarySuffixes()
+default_ignored_suffixes += getExtensionModuleSuffixes()
 
 default_ignored_dirs = (
     "__pycache__",
@@ -312,8 +320,8 @@ def addIncludedDataFile(included_datafile):
         ) or isFilenameBelowPath(
             path=external_datafile_pattern, filename=included_datafile.dest_path
         ):
+            included_datafile.tags.clear()
             included_datafile.tags.add("inhibit")
-            included_datafile.tags.remove("copy")
 
             return
 
@@ -609,9 +617,11 @@ def _handleDataFile(included_datafile, standalone_entry_points):
 
     if "external" in included_datafile.tags:
         dest_path = getOutputPath(included_datafile.dest_path)
+        external = True
     else:
         _checkPathConflict(included_datafile.dest_path, standalone_entry_points)
         dest_path = os.path.join(dist_dir, included_datafile.dest_path)
+        external = False
 
     if included_datafile.kind == "data_blob":
         makePath(os.path.dirname(dest_path))
@@ -629,6 +639,8 @@ def _handleDataFile(included_datafile, standalone_entry_points):
     else:
         assert False, included_datafile
 
+    return external, dest_path
+
 
 def copyDataFiles(standalone_entry_points):
     """Copy the data files needed for standalone distribution.
@@ -639,6 +651,8 @@ def copyDataFiles(standalone_entry_points):
         necessary handling if provided like this.
     """
 
+    data_file_paths = []
+
     for included_datafile in getIncludedDataFiles():
         # TODO: directories should be resolved to files.
         if included_datafile.needsCopy():
@@ -657,13 +671,18 @@ plugins '--embed-*' options. Not done for '%s'."""
                     % included_datafile.dest_path
                 )
 
-            _handleDataFile(
+            external, data_file_path = _handleDataFile(
                 included_datafile=included_datafile,
                 standalone_entry_points=standalone_entry_points,
             )
 
+            if not external:
+                data_file_paths.append(data_file_path)
+
     _reportDataFiles()
 
+    return data_file_paths
+
 
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
