@@ -1,4 +1,4 @@
-#     Copyright 2024, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
+#     Copyright 2025, Kay Hayen, mailto:kay.hayen@gmail.com find license text at end of file
 
 
 """ Module/Package nodes
@@ -20,7 +20,11 @@ from nuitka.PythonVersions import python_version
 from nuitka.SourceCodeReferences import fromFilename
 from nuitka.tree.SourceHandling import parsePyIFile, readSourceCodeFromFilename
 from nuitka.utils.CStrings import encodePythonIdentifierToC
-from nuitka.utils.Importing import getPackageDirFilename
+from nuitka.utils.FileOperations import switchFilenameExtension
+from nuitka.utils.Importing import (
+    getExtensionModuleSuffixes,
+    getPackageDirFilename,
+)
 from nuitka.utils.ModuleNames import ModuleName
 
 from .ChildrenHavingMixins import (
@@ -87,7 +91,7 @@ class PythonModuleBase(NodeBase):
                 level=0,
             )
 
-            # If we can't find the package for Python3.3 that is semi-OK, it might be in a
+            # If we can't find the package for Python3 that is semi-OK, it might be in a
             # namespace package, these have no init code.
             if python_version >= 0x300 and not package_filename:
                 return ()
@@ -743,6 +747,11 @@ class CompiledPythonNamespacePackage(CompiledPythonPackage):
     def isCompiledPythonNamespacePackage():
         return True
 
+    # These have no source code obviously.
+    @staticmethod
+    def getSourceCode():
+        return None
+
 
 def makeUncompiledPythonModule(
     module_name, reason, filename, bytecode, is_package, technical
@@ -1040,14 +1049,18 @@ class PythonExtensionModule(PythonModuleBase):
         """Get Python type description filename."""
 
         path = self.getFilename()
-        filename = os.path.basename(path)
-        dirname = os.path.dirname(path)
 
-        for suffix in (".pyi", ".py"):
-            candidate = os.path.join(dirname, filename.split(".")[0]) + suffix
+        for extension_module_suffix in getExtensionModuleSuffixes():
+            if path.endswith(extension_module_suffix):
+                for pyi_suffix in (".pyi", ".py"):
+                    candidate = switchFilenameExtension(
+                        path=path,
+                        old_extension=extension_module_suffix,
+                        new_extension=pyi_suffix,
+                    )
 
-            if os.path.exists(candidate):
-                return candidate
+                    if os.path.exists(candidate):
+                        return candidate
 
         return None
 
@@ -1055,11 +1068,17 @@ class PythonExtensionModule(PythonModuleBase):
         """Read the .pyi file if present and scan for dependencies."""
 
         if self.used_modules is None:
+            # TODO: Make this a locatePyIFilename function instead.
             pyi_filename = self._getPyIFilename()
 
             if pyi_filename is not None:
                 pyi_deps = parsePyIFile(
                     module_name=self.getFullName(),
+                    package_name=(
+                        self.getFullName()
+                        if self.is_package
+                        else self.getFullName().getPackageName()
+                    ),
                     pyi_filename=pyi_filename,
                 )
 
